==> lftp-2.3.10.tar.gz: lftp-2.3.10/src/StatusLine.h <==
/*
 * lftp and utils
 *
 * Copyright (c) 1996-1997 by Alexander V. Lukyanov (lav@yars.free.net)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/* $Id: StatusLine.h,v 1.6 2001/03/13 08:41:42 lav Exp $ */

#ifndef STATUSLINE_H
#define STATUSLINE_H

#ifdef __GNUC__
# define PRINTF_LIKE(n,m) __attribute__((format(printf,n,m)))
#else
# define PRINTF_LIKE(n,m)
#endif

#include "SMTask.h"

class StatusLine : public SMTask
{
   int fd;
   char shown[0x800];
   bool	not_term;
   time_t update_time;
   char to_be_shown[0x800];
   char def_title[0x800];
   bool update_delayed;
   void update(char *);
   int LastWidth;

protected:
   ~StatusLine();
   void WriteTitle(const char *s, int fd) const;
	   
public:
   int GetWidth();
   int GetWidthDelayed() { return LastWidth; }
   void DefaultTitle(const char *s);
   void Show(const char *f,...) PRINTF_LIKE(2,3);
   void WriteLine(const char *f,...) PRINTF_LIKE(2,3);
   void Clear();

   int getfd() { return fd; }

   StatusLine(int new_fd);

   int Do();
};

#endif // STATUSLINE_H

==> lftp_2.4.9.orig.tar.gz: lftp-2.4.9/src/StatusLine.h <==
/*
 * lftp and utils
 *
 * Copyright (c) 1996-1997 by Alexander V. Lukyanov (lav@yars.free.net)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/* $Id: StatusLine.h,v 1.10 2001/11/08 09:25:48 lav Exp $ */

#ifndef STATUSLINE_H
#define STATUSLINE_H

#include "SMTask.h"
#include "Timer.h"

class StatusLine : public SMTask
{
   int fd;
   char shown[0x800];
   bool	not_term;
   Timer update_timer;
   char to_be_shown[0x800];
   char def_title[0x800];
   bool update_delayed;
   void update(char *);
   int LastWidth;

protected:
   ~StatusLine();
   void WriteTitle(const char *s, int fd) const;

public:
   int GetWidth();
   int GetWidthDelayed() { return LastWidth; }
   void DefaultTitle(const char *s);
   void Show(const char *f,...) PRINTF_LIKE(2,3);
   void WriteLine(const char *f,...) PRINTF_LIKE(2,3);
   void Clear();

   int getfd() { return fd; }

   StatusLine(int new_fd);

   int Do();
};

#endif // STATUSLINE_H
